# PAY.JP for Python

[![Build Status](https://travis-ci.org/payjp/payjp-python.svg?branch=master)](https://travis-ci.org/payjp/payjp-python)

## Installation

Install from PyPi using [pip](http://www.pip-installer.org/en/latest/), a
package manager for Python.

    pip install payjp

Or, you can [download the source code
(ZIP)](https://github.com/payjp/payjp-python/zipball/master "payjp-python
source code") for `payjp-python`, and then run:

    python setup.py install

## Documentation

Please see our official [documentation](https://pay.jp/docs/api).

## Dependencies 

- requests
- six

Install dependencies from using [pip](http://www.pip-installer.org/en/latest/):
    
    pip install -r requirements.txt
